@@ -5,8 +5,15 @@ read_ima <- function(fraw, verbose = FALSE, extra) {
   
   vars <- read_siemens_txt_hdr(res$ascii_hdr, "vd", verbose)
   
-  # calculate expected size of data in bytes - assuming complex 4byte floats
-  data_size <- vars$x_pts * vars$y_pts * vars$z_pts * vars$N * 4 * 2
+  # works for CMRR MPRESS, but not CMRR sLASER
+  if (!vars$rm_oversampling) vars$N <- vars$N * 2
+  
+  # calculate expected size of data points
+  data_size <- vars$x_pts * vars$y_pts * vars$z_pts * vars$N * 2
+  
+  # note that for scans where oversampling is not removed there are actually
+  # twice the number of points in the DICOM tag. However these points seem to
+  # be garbage making this mode useless as half the time-domain data is lost.
   
   raw_pts <- readBin(res$spec_data, what = "double", n = data_size, size = 4L)
   
@@ -16,7 +23,7 @@ read_ima <- function(fraw, verbose = FALSE, extra) {
   data <- array(data, dim = c(vars$N, 1, 1, vars$z_pts, vars$y_pts, vars$x_pts, 
                               1))
   
-  data <- aperm(data, c(7,5,6,4,3,2,1))
+  data <- aperm(data, c(7, 5, 6, 4, 3, 2, 1))
   
   # freq domain vector vector
   freq_domain <- rep(FALSE, 7)
@@ -24,7 +31,11 @@ read_ima <- function(fraw, verbose = FALSE, extra) {
   # get the resolution and geom info
   paras <- calc_siemens_paras(vars, TRUE)
   
-  meta = list(EchoTime = vars$te)
+  meta <- list(EchoTime = vars$te,
+               RepetitionTime = vars$tr,
+               FlipAngle = vars$flip_ang,
+               SequenceName = vars$seq_fname,
+               ChemicalShiftReference = 4.7 + vars$delta_freq)
   
   mrs_data <- mrs_data(data = data, ft = vars$ft, resolution = paras$res,
                        ref = paras$ref, nuc = paras$nuc,
@@ -40,13 +51,14 @@ read_ima <- function(fraw, verbose = FALSE, extra) {
 #' @param dir data directory path.
 #' @param extra an optional data frame to provide additional variables for use
 #' in subsequent analysis steps, eg id or grouping variables.
+#' @param verbose output extra information to the console.
 #' @return mrs_data object.
 #' @export
-read_ima_coil_dir <- function(dir, extra = NULL) {
+read_ima_coil_dir <- function(dir, extra = NULL, verbose = FALSE) {
   files <- list.files(dir, full.names = TRUE)
   #warning("coil ordering is based on file name only.")
   files <- sort(files)
-  mrs_list <- lapply(files, read_mrs, format = "dicom", verbose = TRUE,
+  mrs_list <- lapply(files, read_mrs, format = "dicom", verbose = verbose,
                      extra = extra)
   mrs_data <- append_coils(mrs_list)
   return(mrs_data)
@@ -58,13 +70,14 @@ read_ima_coil_dir <- function(dir, extra = NULL) {
 #' @param dir data directory path.
 #' @param extra an optional data frame to provide additional variables for use
 #' in subsequent analysis steps, eg id or grouping variables.
+#' @param verbose output extra information to the console.
 #' @return mrs_data object.
 #' @export
-read_ima_dyn_dir <- function(dir, extra = NULL) {
+read_ima_dyn_dir <- function(dir, extra = NULL, verbose = FALSE) {
   files <- list.files(dir, full.names = TRUE)
   #warning("coil ordering is based on file name only.")
   files <- sort(files)
-  mrs_list <- lapply(files, read_mrs, format = "dicom", verbose = TRUE,
+  mrs_list <- lapply(files, read_mrs, format = "dicom", verbose = verbose,
                      extra = extra)
   mrs_data <- append_dyns(mrs_list)
   return(mrs_data)
